@@ -12,6 +12,7 @@ import Overridable from "react-overridable";
 import { Button, Divider, Modal, Message } from "semantic-ui-react";
 import { RequestActionModal } from "./RequestActionModal";
 import { Trans } from "react-i18next";
+import { i18next } from "@translations/invenio_requests/i18next";
 
 export class RequestAction extends Component {
   static contextType = RequestActionContext;
@@ -29,13 +30,18 @@ export class RequestAction extends Component {
     const { performAction } = this.context;
     const { action } = this.props;
     const { actionComment } = this.state;
-    performAction(action, actionComment);
+    return performAction(action, actionComment);
   };
 
   render() {
-    const { loading, performAction, toggleModal, error } = this.context;
-    const { action } = this.props;
+    const { loading, performAction, toggleModal, error, modalOpen } = this.context;
+    const { action, requestType } = this.props;
     const modalId = action;
+    const buttonAria = {
+      'aria-expanded': !!modalOpen[modalId],
+      'aria-haspopup': 'dialog',
+      'aria-controls': modalId
+    }
     return (
       <Overridable
         id="InvenioRequests.RequestAction.layout"
@@ -44,13 +50,27 @@ export class RequestAction extends Component {
         performAction={performAction}
       >
         <>
-          <Button onClick={() => toggleModal(modalId, true)} loading={loading}>
-            <Trans defaults="{{action}}" values={{ action: action }} />
-          </Button>
+          <Overridable
+            id={`RequestAction.button.${action}`}
+            onClick={() => toggleModal(modalId, true)}
+            loading={loading}
+            action={action}
+            requestType={requestType}
+            ariaAttributes={buttonAria}
+          >
+            <Button
+              onClick={() => toggleModal(modalId, true)}
+              loading={loading}
+              {...buttonAria}
+            >
+              {action}
+            </Button>
+          </Overridable>
           <RequestActionModal
             action={action}
             handleActionClick={this.handleActionClick}
             modalId={modalId}
+            requestType={requestType}
           >
             <Modal.Content>
               {error && (
@@ -58,12 +78,8 @@ export class RequestAction extends Component {
                   <p>{error}</p>
                 </Message>
               )}
-
               <Modal.Description>
-                <Trans
-                  defaults="Comment on your {{action}} request action (optional)."
-                  values={{ action: action }}
-                />
+                {i18next.t("Add comment (optional)")}
                 <Divider hidden />
                 <FormattedInputEditor onChange={this.onCommentChange} />
               </Modal.Description>
@@ -77,6 +93,7 @@ export class RequestAction extends Component {
 
 RequestAction.propTypes = {
   action: PropTypes.string.isRequired,
+  requestType: PropTypes.string.isRequired,
 };
 
 export default Overridable.component(
